The :term:`workspace` allows grouping of :term:`resources <resource>` in a logical way. A workspace can be considered a single point for a particular environment, set of services, or some other logical grouping. It can also be just one big storage bin of all managed resources.

The workspace can be specified on the command line with the ``--workspace`` or ``-w`` option, followed by the workspace path. It can also be specified with an environment variable. (eg. ``$WORKSPACE`` in bash).
